@@ -14,6 +14,7 @@ from . import types
 from .circuitmap import CircuitMap  # noqa
 from .connection import CommandError  # noqa
 from .connection import Connection  # noqa
+from .connection import EbusdShutdown  # noqa
 from .const import AUTO  # noqa
 from .const import NA  # noqa
 from .const import OK  # noqa
@@ -27,5 +28,7 @@ from .msgdecoder import MsgDecoder  # noqa
 from .msgdecoder import UnknownMsgError  # noqa
 from .msgdef import FieldDef  # noqa
 from .msgdef import MsgDef  # noqa
+from .msgdef import VirtFieldDef  # noqa
+from .msgdef import resolve_prio  # noqa
 from .msgdefdecoder import decode_msgdef  # noqa
 from .msgdefs import MsgDefs  # noqa
