@@ -1,6 +1,13 @@
 """Listen Command."""
 
-from .common import add_msgdef_args, add_patterns_arg, create_ebus, disable_stdout_buffering, load_msgdefs, print_msg
+from .common import (
+    add_msgdef_args,
+    add_patterns_arg,
+    async_load_msgdefs,
+    create_ebus,
+    disable_stdout_buffering,
+    print_msg,
+)
 
 
 def parse_args(subparsers):
@@ -14,9 +21,9 @@ def parse_args(subparsers):
 async def _main(args):
     disable_stdout_buffering()
     ebus = create_ebus(args)
-    await load_msgdefs(ebus, args)
+    await async_load_msgdefs(ebus, args)
     msgdefs = ebus.msgdefs.resolve(args.patterns.split(";"))
     print(f"Listening to {msgdefs.summary()}")
     if msgdefs:
-        async for msg in ebus.listen(msgdefs=msgdefs):
+        async for msg in ebus.async_listen(msgdefs=msgdefs):
             print_msg(msg)
