@@ -90,7 +90,6 @@ class Connection:
         Send `message`.
 
         Raises:
-            IOError: If connection is broken or cannot be established (`autoconnect==True`)
             ConnectionError: If not connected (`autoconnect==False`)
         """
         _LOGGER.debug(f"write({message!r})")
@@ -163,7 +162,7 @@ class Connection:
             try:
                 result = await asyncio.wait_for(task, timeout=self._timeout)
             except asyncio.TimeoutError as timeout:
-                raise ConnectionTimeout(f"{self.host}:{self.port}") from timeout
+                raise ConnectionError(f"{self.host}:{self.port} timeout") from timeout
         else:
             result = await task
         return result
@@ -174,15 +173,7 @@ class CommandError(RuntimeError):
     """Command Error raised in case of EBUSD error."""
 
 
-class ConnectionTimeout(RuntimeError):
-
-    """Connection Timeout."""
-
-    def __str__(self):
-        return "Connection Timeout."
-
-
-class EbusdShutdown(RuntimeError):
+class EbusdShutdown(ConnectionError):
 
     """Shutdown."""
 
