@@ -3,7 +3,7 @@ import asyncio
 import collections
 import logging
 
-from .connection import CommandError, Connection, ConnectionTimeout
+from .connection import CommandError, Connection
 from .const import OK
 from .msg import BrokenMsg, filter_msg
 from .msgdecoder import MsgDecoder, UnknownMsgError
@@ -231,12 +231,12 @@ class Ebus:
     async def _async_get_state(self):
         try:
             await self.connection.async_request("state")
-            state = await self.connection.async_readresp()
+            state = await self.connection.async_readresp(check=False)
             if state.startswith("signal acquired"):
                 return OK
             else:
                 return state
-        except (ConnectionError, ConnectionTimeout):
+        except (ConnectionError, CommandError):
             return "no ebusd connection"
 
     async def async_is_online(self):
