@@ -1,7 +1,7 @@
 """EBUS Messages And Their Fields."""
 import collections
 
-from .na import NA
+from .const import NA
 from .util import repr_
 
 Error = collections.namedtuple("Error", "msg")
